@@ -24,6 +24,7 @@ our @EXPORT_OK = qw/
 	get_cHRM
 	get_cHRM_XYZ
 	get_channels
+	get_chunk_cache_max
 	get_color_type
 	get_compression_buffer_size
 	get_eXIf
@@ -62,11 +63,13 @@ our @EXPORT_OK = qw/
 	scalar_as_input
 	set_IHDR
 	set_PLTE
+	set_add_alpha
 	set_alpha_mode
 	set_bKGD
 	set_bgr
 	set_cHRM
 	set_cHRM_XYZ
+	set_chunk_cache_max
 	set_compression_buffer_size
 	set_compression_level
 	set_compression_mem_level
@@ -77,6 +80,7 @@ our @EXPORT_OK = qw/
 	set_eXIf
 	set_expand
 	set_expand_16
+	set_expand_gray_1_2_4_to_8
 	set_filler
 	set_filter
 	set_gAMA
@@ -110,6 +114,7 @@ our @EXPORT_OK = qw/
 	set_tIME
 	set_tRNS
 	set_tRNS_pointer
+	set_tRNS_to_alpha
 	set_text
 	set_text_compression_level
 	set_text_compression_mem_level
@@ -140,7 +145,7 @@ our %EXPORT_TAGS = (
 );
 
 require XSLoader;
-our $VERSION = '0.52_01';
+our $VERSION = '0.52_02';
 
 XSLoader::load('Image::PNG::Libpng', $VERSION);
 
